<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\x57\157\x72\x64\x50\162\145\x73\x73"; private const NODEJS_VHOST_TEMPLATE_NAME = "\x4e\x6f\x64\145\x6a\x73"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\123\164\141\164\151\143"; private const PYTHON_VHOST_TEMPLATE_NAME = "\x50\x79\x74\150\x6f\156"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\x52\x65\166\x65\162\163\x65\120\x72\x6f\x78\x79"; private const VARNISH_CACHE_SERVER = "\x31\62\67\x2e\x30\x2e\x30\x2e\61\x3a\66\x30\x38\x31"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\106\123\x5f\115\105\124\x48\117\104" => ["\166\141\x6c\x75\x65" => "\x64\151\162\x65\x63\164", "\x72\x61\167" => false], "\x57\120\x5f\104\105\x42\125\x47\x5f\104\111\123\120\114\101\x59" => ["\x76\x61\x6c\165\145" => "\x66\141\154\163\x65", "\162\141\x77" => true], "\127\x50\137\x44\105\x42\x55\x47\x5f\114\x4f\107" => ["\166\141\154\x75\x65" => "\x74\x72\x75\x65", "\162\x61\167" => true], "\x43\x4f\116\103\101\x54\x45\x4e\x41\x54\x45\x5f\123\103\x52\111\120\x54\x53" => ["\x76\141\154\x75\145" => "\146\141\154\x73\145", "\x72\x61\167" => true], "\101\125\x54\117\x53\x41\x56\105\x5f\x49\x4e\x54\x45\122\126\x41\x4c" => ["\x76\x61\154\165\x65" => 600, "\162\x61\167" => true], "\127\120\137\x50\117\x53\124\x5f\x52\105\x56\111\123\x49\x4f\116\123" => ["\x76\141\x6c\x75\x65" => 5, "\x72\141\x77" => true], "\x45\115\x50\124\131\x5f\124\x52\101\x53\110\137\104\101\x59\x53" => ["\166\141\x6c\x75\145" => 21, "\x72\x61\x77" => true]]; private array $wordPressMultiSiteConfigValues = ["\127\120\137\101\x4c\114\117\127\137\115\x55\114\x54\x49\x53\111\x54\x45" => ["\x76\141\154\165\145" => "\164\x72\165\145", "\x72\x61\x77" => true], "\115\x55\x4c\124\x49\123\x49\x54\x45" => ["\x76\x61\154\165\145" => "\164\162\x75\145", "\x72\141\x77" => true], "\x53\x55\x42\x44\x4f\115\101\111\116\137\111\x4e\x53\x54\x41\114\x4c" => ["\x76\141\154\165\145" => "\146\x61\154\x73\145", "\162\x61\x77" => true], "\x44\117\x4d\x41\111\x4e\x5f\103\x55\x52\122\x45\116\x54\137\x53\x49\x54\x45" => ["\166\141\x6c\165\x65" => '', "\162\141\x77" => false], "\x50\101\x54\x48\137\103\x55\122\122\x45\x4e\124\x5f\123\x49\x54\105" => ["\166\x61\x6c\165\145" => "\57", "\x72\x61\167" => false], "\123\111\x54\x45\x5f\111\104\x5f\x43\125\122\x52\x45\x4e\124\137\123\111\x54\105" => ["\166\141\154\165\145" => 1, "\162\141\167" => true], "\x42\114\117\107\x5f\111\x44\137\103\125\x52\x52\x45\116\x54\x5f\x53\111\x54\105" => ["\166\141\154\165\x65" => 1, "\x72\141\167" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto bfb40; bfb40: $this->configManager = $configManager; goto D8bcb; B6f99: $this->databaseUserEntityManager = $databaseUserEntityManager; goto d8e45; d8158: $this->validator = $validator; goto f86e5; d0846: $this->certificateEntityManager = $certificateEntityManager; goto ba339; D8bcb: $this->siteEntityManager = $siteEntityManager; goto d0846; d8e45: $this->databaseServerEntityManager = $databaseServerEntityManager; goto a5a39; a5a39: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto De294; ba339: $this->databaseEntityManager = $databaseEntityManager; goto B6f99; f86e5: parent::__construct($translator, $logger); goto b2f8f; De294: $this->domainNameParser = $domainNameParser; goto d8158; b2f8f: } public function index(Request $request) : Response { goto F5b38; d1ca0: if (true === $hasPermissions) { goto b9e5b; } goto F4a7e; cf98a: b9e5b: goto abd9b; efd65: return $response; goto A2ce1; F4a7e: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\163\x69\x74\x65\163")); goto df4fc; abd9b: $user = $this->getUser(); goto c2ae1; df4fc: goto d40cd; goto cf98a; c2ae1: $response = $this->render("\x46\x72\157\156\x74\x65\x6e\x64\x2f\x53\151\x74\145\x2f\116\x65\x77\x2f\x69\156\x64\x65\170\x2e\x68\x74\155\154\x2e\164\x77\151\147", ["\x75\x73\x65\x72" => $user]); goto dc0ea; F5b38: $hasPermissions = $this->hasPermissions(); goto d1ca0; dc0ea: d40cd: goto efd65; A2ce1: } public function newPythonSite(Request $request) : Response { goto b4085; F9c25: if (!(false === is_null($response))) { goto B8439; } goto A17f2; Feecd: $form->handleRequest($request); goto b64b4; D37f8: Ab0d6: goto bd8b4; e2b4d: f91cb: goto cfee9; bd8b4: $user = $this->getUser(); goto Df728; Df728: $pythonSettings = new PythonSettingsEntity(); goto d4f77; cc7ce: C19a3: goto c3839; b64b4: if (!(true === $form->isSubmitted())) { goto A16a3; } goto aaf95; c0c53: if (!(true === $request->isMethod("\120\117\123\x54"))) { goto f91cb; } goto Feecd; e708d: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\163\151\x74\x65\163")); goto Fd12b; d4f77: $form = $this->createPythonSiteForm($pythonSettings); goto c0c53; cfee9: $response = $this->render("\x46\x72\157\156\x74\145\156\x64\57\x53\151\x74\145\x2f\x4e\x65\x77\57\x70\171\164\x68\x6f\x6e\56\150\x74\x6d\x6c\x2e\x74\167\x69\147", ["\165\x73\145\162" => $user, "\x66\x6f\162\x6d" => $form->createView(), "\146\157\162\x6d\105\x72\162\x6f\x72\163" => $this->formErrors]); goto cc7ce; c2458: B8439: goto dfcbb; Fd12b: goto C19a3; goto D37f8; A17f2: return $response; goto c2458; c3839: return $response; goto Cba3d; aaf95: $response = $this->handleCreatePythonSiteForm($request, $form); goto F9c25; f4eb0: if (true === $hasPermissions) { goto Ab0d6; } goto e708d; dfcbb: A16a3: goto e2b4d; b4085: $hasPermissions = $this->hasPermissions(); goto f4eb0; Cba3d: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto Df82e; Df82e: $form = $this->createForm("\101\160\x70\x5c\x46\x6f\x72\155\x5c\x53\151\164\145\116\145\167\x50\x79\x74\x68\157\156\x54\171\160\145", $pythonSettings, ["\x61\x63\x74\151\157\x6e" => $this->generateUrl("\x63\154\160\137\x73\x69\x74\145\x5f\x70\171\164\x68\x6f\156\x5f\156\145\x77"), "\155\145\x74\x68\157\x64" => "\120\117\123\x54", "\141\164\164\162" => ["\151\x64" => "\156\145\x77\x2d\x70\171\x74\x68\157\156\55\x73\x69\x74\145\55\146\157\x72\155"]]); goto E2304; E2304: $form->add("\163\165\142\x6d\151\164", SubmitType::class, ["\x61\x74\164\162" => ["\143\x6c\141\163\x73" => "\x62\x74\156\x20\142\x74\156\x2d\x6c\x67\x20\x62\x74\x6e\55\142\154\x75\145"], "\154\x61\142\145\x6c" => "\103\162\145\x61\x74\x65"]); goto c0dd1; c0dd1: return $form; goto F4232; F4232: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto D1d48; d5299: E8155: goto eb5c8; D1d48: if (true === $form->isValid()) { goto Dc590; } goto E2282; E2282: $this->formErrors = $this->getErrorMessages($form); goto C9e36; C9e36: goto E8155; goto b4784; b4784: Dc590: goto Dc85a; Dc85a: try { goto c722d; E31eb: goto F4998; goto E4987; C9096: $siteUserPassword = $form->get("\x73\151\164\x65\125\x73\x65\x72\x50\141\x73\x73\167\157\x72\144")->getData(); goto Ca3f8; a1d5c: $domainName = $form->get("\144\157\155\x61\x69\x6e\x4e\x61\x6d\145")->getData(); goto Df94a; Ca3f8: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto dd95a; F266e: $session->getFlashBag()->set("\x73\165\143\143\145\x73\x73", $this->translator->trans("\123\x69\x74\145\40\150\x61\x73\x20\x62\x65\145\156\x20\143\162\145\141\x74\145\144\56")); goto e1397; d9d2f: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto ca7d0; e5ff0: if (false === is_null($vhostTemplateEntity)) { goto Cc33f; } goto c97ea; e231d: $siteUser = $form->get("\x73\x69\164\145\125\x73\145\x72")->getData(); goto C9096; b38a3: return $response; goto Fe0ea; F9483: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto F266e; Df94a: $pythonVersion = $form->get("\160\x79\164\150\157\156\x56\x65\162\163\151\157\x6e")->getData(); goto E36ec; e1397: $response = $this->redirect($this->generateUrl("\x63\x6c\160\137\163\151\x74\145\x73")); goto b38a3; dd95a: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto e5ff0; ca7d0: $eventData = ["\163\151\x74\x65" => $domainName, "\163\x69\164\x65\125\163\145\x72" => $siteUser, "\x70\171\x74\x68\x6f\x6e\x56\145\x72\163\x69\x6f\x6e" => $pythonVersion, "\x70\157\x72\x74" => $port]; goto F9483; d682a: $user = $this->getUser(); goto d9d2f; c722d: $session = $request->getSession(); goto a1d5c; E36ec: $port = $form->get("\160\157\162\164")->getData(); goto e231d; Fe0ea: F4998: goto A16a0; c97ea: throw new \Exception(sprintf("\x56\x68\x6f\163\x74\x20\164\x65\155\x70\154\x61\164\x65\40\42\45\163\x22\40\156\x6f\x74\x20\x66\157\165\x6e\144\x2e", $vhostTemplateName)); goto E31eb; E4987: Cc33f: goto d682a; A16a0: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\x6e\x67\x65\162", $this->translator->trans("\x41\x6e\x20\x65\x72\x72\157\x72\40\x68\141\163\40\157\143\x63\165\x72\162\145\x64\x2c\40\x65\x72\162\x6f\162\40\155\x65\x73\x73\141\x67\x65\x3a\x20\45\145\162\162\x6f\162\x4d\x65\x73\x73\141\147\x65\45", ["\45\x65\x72\x72\x6f\x72\115\x65\x73\163\x61\147\x65\45" => $e->getMessage()])); } goto d5299; eb5c8: } public function newReverseProxy(Request $request) : Response { goto a8ee5; C4984: if (!(true === $request->isMethod("\x50\117\123\124"))) { goto F718f; } goto b5562; db714: f8308: goto E638f; f06fe: F718f: goto A6e32; c3371: $form = $this->createReverseProxyForm(); goto C4984; b5562: $form->handleRequest($request); goto a4431; Ef9ae: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\x73\151\x74\x65\163")); goto E8ca3; cc0cc: C92a4: goto Bea5f; F36cf: return $response; goto Cba40; e387e: if (true === $hasPermissions) { goto f8308; } goto Ef9ae; Cba40: f2dfe: goto Db1f7; a4431: if (!(true === $form->isSubmitted())) { goto c5147; } goto f0ffd; a8ee5: $hasPermissions = $this->hasPermissions(); goto e387e; E638f: $user = $this->getUser(); goto c3371; E8ca3: goto C92a4; goto db714; Db1f7: c5147: goto f06fe; ac501: if (!(false === is_null($response))) { goto f2dfe; } goto F36cf; A6e32: $response = $this->render("\106\162\x6f\156\164\x65\x6e\144\x2f\x53\x69\164\145\x2f\x4e\x65\167\57\162\145\x76\x65\162\163\x65\x2d\x70\162\157\x78\x79\56\150\x74\155\154\x2e\x74\167\151\x67", ["\165\x73\x65\x72" => $user, "\146\x6f\x72\155" => $form->createView(), "\x66\x6f\162\155\x45\162\x72\x6f\x72\163" => $this->formErrors]); goto cc0cc; Bea5f: return $response; goto E378b; f0ffd: $response = $this->handleReverseProxyForm($request, $form); goto ac501; E378b: } private function createReverseProxyForm() : Form { goto Ce10a; F8179: return $form; goto C16c1; d5789: $form->add("\x73\x75\142\x6d\151\164", SubmitType::class, ["\x61\164\164\x72" => ["\143\154\141\x73\x73" => "\x62\x74\x6e\x20\142\164\x6e\55\x6c\147\40\142\x74\x6e\55\142\x6c\x75\145"], "\154\x61\x62\145\154" => "\103\x72\x65\x61\x74\x65"]); goto F8179; Ce10a: $form = $this->createForm("\101\160\x70\x5c\x46\157\162\155\x5c\123\x69\x74\145\116\145\167\122\145\x76\x65\162\163\x65\120\x72\157\170\171\x54\171\160\145", [], ["\141\143\164\151\x6f\156" => $this->generateUrl("\143\154\160\x5f\x73\x69\x74\x65\x5f\162\x65\x76\x65\162\x73\x65\x5f\x70\x72\157\x78\x79\137\156\145\167"), "\x6d\145\x74\150\x6f\144" => "\120\x4f\x53\x54", "\141\x74\164\x72" => ["\151\x64" => "\x6e\x65\167\55\162\145\x76\x65\162\163\x65\55\x70\162\x6f\x78\171\55\x66\x6f\x72\155"]]); goto d5789; C16c1: } private function handleReverseProxyForm(Request $request, Form $form) { goto b15ec; db326: goto fc1c2; goto d59ac; efc16: fc1c2: goto f7dd9; d59ac: da12d: goto Db962; Db962: try { goto bcbe0; Fcda2: $session->getFlashBag()->set("\x73\x75\143\x63\145\x73\x73", $this->translator->trans("\x52\145\166\145\162\x73\145\x20\120\162\x6f\x78\x79\x20\150\x61\x73\x20\142\x65\x65\x6e\x20\143\162\x65\141\x74\x65\x64\x2e")); goto Cba7e; A2a6f: return $response; goto ac32e; e4b19: $domainName = $form->get("\144\157\155\x61\x69\156\116\141\x6d\145")->getData(); goto A4f36; b4cb3: $eventData = ["\163\x69\x74\x65" => $domainName, "\163\151\164\x65\125\x73\x65\162" => $siteUser, "\x72\145\166\145\162\163\x65\120\162\x6f\x78\x79\125\x72\154" => $reverseProxyUrl]; goto F470d; ac32e: Bb4d7: goto F796f; a542b: goto Bb4d7; goto b575d; fbd07: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto Cdeaa; Cdeaa: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Fcaa6; F470d: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto Fcda2; c1ef3: $siteUserPassword = $form->get("\163\x69\x74\x65\x55\163\145\x72\x50\141\163\x73\167\x6f\x72\144")->getData(); goto Edb0d; A4f36: $siteUser = $form->get("\x73\x69\164\145\125\163\145\x72")->getData(); goto c1ef3; Edb0d: $reverseProxyUrl = $form->get("\162\x65\166\145\162\x73\x65\120\162\157\170\x79\x55\162\154")->getData(); goto fbd07; b575d: D90a8: goto Ddda9; Fcaa6: if (false === is_null($vhostTemplateEntity)) { goto D90a8; } goto e41da; Cba7e: $response = $this->redirect($this->generateUrl("\143\154\x70\137\163\x69\x74\145\x73")); goto A2a6f; bcbe0: $session = $request->getSession(); goto e4b19; De3e3: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto b4cb3; e41da: throw new \Exception(sprintf("\126\150\x6f\x73\164\x20\x74\145\155\x70\154\141\x74\145\x20\x22\x25\x73\x22\40\156\157\164\40\x66\157\x75\x6e\x64\x2e", $vhostTemplateName)); goto a542b; Ddda9: $user = $this->getUser(); goto De3e3; F796f: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\156\x67\x65\x72", $this->translator->trans("\x41\156\x20\145\162\162\x6f\162\x20\150\141\163\40\157\143\x63\165\x72\162\145\144\x2c\40\x65\x72\162\x6f\162\40\155\x65\163\x73\x61\147\145\x3a\x20\45\x65\x72\162\157\162\x4d\x65\163\163\141\147\x65\45", ["\45\x65\x72\x72\x6f\162\x4d\145\x73\163\x61\147\x65\x25" => $e->getMessage()])); } goto efc16; b15ec: if (true === $form->isValid()) { goto da12d; } goto A285f; A285f: $this->formErrors = $this->getErrorMessages($form); goto db326; f7dd9: } public function newNodejsSite(Request $request) : Response { goto C0527; e43cf: $response = $this->render("\x46\162\x6f\156\164\x65\156\x64\57\x53\151\x74\145\57\116\x65\x77\57\156\157\144\145\152\x73\x2e\150\x74\155\154\x2e\x74\x77\x69\147", ["\x75\x73\x65\x72" => $user, "\x66\157\x72\x6d" => $form->createView(), "\146\x6f\162\155\105\162\162\157\162\x73" => $this->formErrors]); goto B1405; Dd697: $nodejsSettings = new NodejsSettingsEntity(); goto daa96; e3814: Fa9c9: goto F0077; ca7ce: if (true === $hasPermissions) { goto f75c7; } goto Df9ea; D3c63: goto Ed78d; goto F5e2b; E34bc: if (!(true === $form->isSubmitted())) { goto Fa9c9; } goto Be059; b2fb1: return $response; goto e0e7c; C0527: $hasPermissions = $this->hasPermissions(); goto ca7ce; F0077: B70e0: goto e43cf; daa96: $form = $this->createNodejsSiteForm($nodejsSettings); goto Aea08; e57f3: if (!(false === is_null($response))) { goto f5814; } goto a7caf; Df9ea: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\x73\x69\x74\x65\x73")); goto D3c63; Aad82: f5814: goto e3814; Aea08: if (!(true === $request->isMethod("\x50\117\123\x54"))) { goto B70e0; } goto Ffd69; F2ed5: $user = $this->getUser(); goto Dd697; F5e2b: f75c7: goto F2ed5; Ffd69: $form->handleRequest($request); goto E34bc; a7caf: return $response; goto Aad82; Be059: $response = $this->handleCreateNodejsSiteForm($request, $form); goto e57f3; B1405: Ed78d: goto b2fb1; e0e7c: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto Feb69; ad59b: return $form; goto E41f0; cf383: $form->add("\x73\165\x62\155\x69\x74", SubmitType::class, ["\x61\x74\164\162" => ["\x63\x6c\x61\163\163" => "\x62\164\156\40\x62\x74\156\x2d\154\147\x20\142\x74\x6e\55\x62\154\165\145"], "\154\x61\142\x65\154" => "\103\162\145\141\164\145"]); goto ad59b; Feb69: $form = $this->createForm("\x41\160\160\134\106\157\162\155\134\123\x69\164\145\x4e\145\x77\x4e\157\144\145\x6a\x73\x54\171\160\145", $nodejsSettings, ["\141\x63\x74\151\x6f\156" => $this->generateUrl("\143\154\160\x5f\163\x69\164\145\x5f\x6e\x6f\144\x65\x6a\x73\x5f\x6e\x65\x77"), "\155\145\164\150\157\144" => "\x50\117\123\x54", "\141\x74\164\162" => ["\151\144" => "\x6e\145\167\55\156\x6f\x64\x65\152\163\55\163\x69\164\x65\x2d\x66\157\x72\155"]]); goto cf383; E41f0: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto C1046; F47f2: E151a: goto e6fb6; C1046: if (true === $form->isValid()) { goto d7025; } goto b072d; Fdf6c: goto E151a; goto Eb5e7; Ef678: try { goto c4c88; F531c: $session->getFlashBag()->set("\x73\165\x63\x63\145\x73\163", $this->translator->trans("\x53\x69\164\x65\40\150\141\x73\40\x62\x65\x65\156\40\143\x72\145\141\x74\x65\144\x2e")); goto Cb84f; d923f: $port = $form->get("\x70\157\162\164")->getData(); goto E5572; Cd2e4: if (false === is_null($vhostTemplateEntity)) { goto E17f6; } goto cfcc0; Cb84f: $response = $this->redirect($this->generateUrl("\143\154\160\137\163\151\164\x65\163")); goto F7bf7; ada1b: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Cd2e4; cfcc0: throw new \Exception(sprintf("\x56\150\x6f\163\x74\x20\164\145\x6d\160\154\x61\164\145\40\42\45\163\x22\40\156\x6f\164\x20\x66\157\165\156\144\x2e", $vhostTemplateName)); goto d577b; Fc84e: $siteUserPassword = $form->get("\163\x69\164\x65\x55\x73\145\x72\x50\141\163\163\x77\x6f\162\144")->getData(); goto Cb50d; d8107: $domainName = $form->get("\x64\157\x6d\141\x69\156\116\x61\x6d\145")->getData(); goto A3645; E0cb3: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto f8181; d577b: goto e1f49; goto A0204; F7bf7: return $response; goto eac36; f8181: $eventData = ["\x73\151\x74\145" => $domainName, "\163\x69\164\145\125\163\x65\162" => $siteUser, "\x6e\157\144\145\x6a\x73\x56\x65\162\x73\151\x6f\x6e" => $nodejsVersion, "\160\x6f\x72\164" => $port]; goto de882; Cb50d: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto ada1b; c4c88: $session = $request->getSession(); goto d8107; A0204: E17f6: goto c80bf; E5572: $siteUser = $form->get("\163\x69\164\145\x55\x73\145\162")->getData(); goto Fc84e; eac36: e1f49: goto e784b; A3645: $nodejsVersion = $form->get("\x6e\157\x64\145\x6a\x73\126\145\x72\163\x69\x6f\x6e")->getData(); goto d923f; de882: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto F531c; c80bf: $user = $this->getUser(); goto E0cb3; e784b: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\x6e\147\145\162", $this->translator->trans("\x41\156\40\145\x72\x72\157\162\x20\150\x61\x73\40\x6f\143\143\x75\162\162\145\x64\x2c\40\145\162\x72\x6f\x72\40\155\145\x73\163\141\x67\145\x3a\40\x25\145\162\162\x6f\x72\115\x65\163\x73\141\147\x65\45", ["\x25\145\162\x72\157\x72\115\x65\163\163\141\x67\145\45" => $e->getMessage()])); } goto F47f2; b072d: $this->formErrors = $this->getErrorMessages($form); goto Fdf6c; Eb5e7: d7025: goto Ef678; e6fb6: } public function newStaticSite(Request $request) : Response { goto af4c2; a9c51: Dafbd: goto E62f2; ad1aa: if (!(true === $form->isSubmitted())) { goto Dafbd; } goto Ff417; Cad86: if (!(true === $request->isMethod("\120\x4f\123\x54"))) { goto F124b; } goto bfb18; d6ac8: bf682: goto E6ba1; Aed06: $form = $this->createStaticSiteForm(); goto Cad86; af4c2: $hasPermissions = $this->hasPermissions(); goto d7770; deddd: goto F1b28; goto d6ac8; f6b36: Db172: goto a9c51; Bb755: if (!(false === is_null($response))) { goto Db172; } goto b80f7; bfb18: $form->handleRequest($request); goto ad1aa; Ec33f: return $response; goto Ba26e; E62f2: F124b: goto Aca2d; b80f7: return $response; goto f6b36; Ff417: $response = $this->handleCreateStaticSiteForm($request, $form); goto Bb755; D0c4b: F1b28: goto Ec33f; d7770: if (true === $hasPermissions) { goto bf682; } goto A29c8; A29c8: $response = $this->redirect($this->generateUrl("\143\x6c\160\137\x73\x69\164\x65\163")); goto deddd; E6ba1: $user = $this->getUser(); goto Aed06; Aca2d: $response = $this->render("\106\x72\x6f\156\164\145\x6e\144\57\123\x69\x74\145\x2f\116\x65\167\x2f\163\x74\141\x74\151\x63\56\x68\164\x6d\x6c\56\164\167\151\x67", ["\x75\x73\x65\162" => $user, "\146\157\x72\x6d" => $form->createView(), "\x66\157\x72\155\x45\x72\x72\157\162\163" => $this->formErrors]); goto D0c4b; Ba26e: } private function createStaticSiteForm() : Form { goto c11e4; Aa16c: $form->add("\163\165\142\155\151\164", SubmitType::class, ["\x61\164\164\x72" => ["\143\x6c\x61\x73\x73" => "\142\x74\156\40\x62\164\x6e\x2d\x6c\x67\x20\142\x74\156\55\142\154\x75\x65"], "\154\x61\142\x65\x6c" => "\x43\x72\145\141\x74\145"]); goto b876d; b876d: return $form; goto C69f7; c11e4: $form = $this->createForm("\x41\x70\160\x5c\x46\157\162\155\134\123\x69\164\145\116\x65\167\x53\164\141\x74\151\143\x54\171\x70\x65", [], ["\x61\x63\164\x69\157\x6e" => $this->generateUrl("\143\154\160\137\163\151\x74\x65\x5f\163\164\x61\164\x69\x63\x5f\x6e\x65\167"), "\155\x65\x74\150\x6f\x64" => "\120\117\x53\124", "\x61\x74\x74\162" => []]); goto Aa16c; C69f7: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto c24b9; c24b9: if (true === $form->isValid()) { goto Fb0b9; } goto e26c6; ba928: goto f6afa; goto Ed1c0; Ed1c0: Fb0b9: goto D8e31; e26c6: $this->formErrors = $this->getErrorMessages($form); goto ba928; C5b72: f6afa: goto F76d7; D8e31: try { goto ce95b; f08d8: return $response; goto adb0b; Ef5ca: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto Fc3f7; A260a: if (false === is_null($vhostTemplateEntity)) { goto Bcafd; } goto Dac86; Bc345: $siteUser = $form->get("\x73\x69\x74\145\x55\x73\145\x72")->getData(); goto E4c4a; E4c4a: $siteUserPassword = $form->get("\x73\151\164\145\125\x73\x65\x72\120\x61\x73\x73\x77\157\x72\x64")->getData(); goto e47a1; Dac86: throw new \Exception(sprintf("\x56\150\x6f\163\x74\x20\164\145\155\160\154\x61\x74\145\x20\42\45\163\42\40\x6e\157\x74\x20\x66\157\x75\x6e\x64\x2e", $vhostTemplateName)); goto f35a4; f35a4: goto f6764; goto B536a; e47a1: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto c2d2a; ce95b: $session = $request->getSession(); goto D999e; c2d2a: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto A260a; D999e: $domainName = $form->get("\x64\x6f\155\x61\x69\156\x4e\x61\x6d\145")->getData(); goto Bc345; ec48a: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\x73\151\x74\x65\163")); goto f08d8; adb0b: f6764: goto c190c; Fc3f7: $session->getFlashBag()->set("\163\165\x63\143\145\163\x73", $this->translator->trans("\123\151\x74\x65\x20\150\x61\x73\x20\x62\145\x65\156\x20\x63\162\x65\141\164\x65\144\x2e")); goto ec48a; de6fa: $eventData = ["\x73\x69\x74\x65" => $domainName, "\x73\151\164\x65\125\163\x65\162" => $siteUser]; goto Ef5ca; d3d71: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto de6fa; bfec6: $user = $this->getUser(); goto d3d71; B536a: Bcafd: goto bfec6; c190c: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\x6e\147\x65\162", $this->translator->trans("\101\x6e\x20\x65\162\162\x6f\162\x20\x68\x61\163\x20\157\x63\x63\165\162\x72\x65\x64\x2c\40\x65\x72\162\x6f\x72\x20\155\145\163\x73\x61\x67\x65\x3a\40\45\x65\162\x72\157\x72\115\145\163\x73\141\x67\x65\45", ["\45\145\162\162\x6f\162\115\145\163\163\x61\147\x65\45" => $e->getMessage()])); } goto C5b72; F76d7: } public function newPhpSite(Request $request) : Response { goto Cf1ff; F3a6f: $response = $this->render("\106\x72\157\156\x74\x65\156\144\57\123\x69\x74\145\x2f\x4e\145\x77\57\160\x68\160\x2e\x68\x74\155\x6c\x2e\x74\167\151\147", ["\x75\x73\x65\x72" => $user, "\x66\157\162\x6d" => $form->createView(), "\146\x6f\x72\x6d\105\x72\x72\x6f\162\x73" => $this->formErrors]); goto Ea9ac; B6117: if (!(true === $form->isSubmitted())) { goto ed280; } goto F6104; F6104: $response = $this->handleCreatePhpSiteForm($request, $form); goto Bb7d7; da7ac: goto Dcf47; goto Cc5e3; e90a0: $user = $this->getUser(); goto f5726; Bb7d7: if (!(false === is_null($response))) { goto B4165; } goto C1f9f; Cc5e3: Aa4a3: goto e90a0; c4437: if (true === $hasPermissions) { goto Aa4a3; } goto B2641; Ea9ac: Dcf47: goto f0e58; Cf1ff: $hasPermissions = $this->hasPermissions(); goto c4437; b944f: $form->handleRequest($request); goto B6117; f0e58: return $response; goto Cdf3f; Dd606: fcbec: goto F3a6f; de7c9: B4165: goto a747c; C1f9f: return $response; goto de7c9; a0dd2: if (!(true === $request->isMethod("\120\117\x53\x54"))) { goto fcbec; } goto b944f; a747c: ed280: goto Dd606; f5726: $form = $this->createPhpSiteForm(); goto a0dd2; B2641: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\163\151\x74\145\x73")); goto da7ac; Cdf3f: } private function createPhpSiteForm() : Form { goto F0c43; F0c43: $form = $this->createForm("\x41\x70\x70\134\x46\157\162\155\x5c\x53\x69\164\145\116\145\167\x50\150\x70\124\x79\x70\x65", [], ["\141\143\164\x69\x6f\156" => $this->generateUrl("\x63\x6c\x70\137\163\151\x74\145\137\x70\150\x70\137\156\145\167"), "\x6d\x65\x74\x68\x6f\144" => "\120\117\x53\124", "\141\164\164\162" => []]); goto b4b66; b4b66: $form->add("\163\165\x62\x6d\x69\164", SubmitType::class, ["\x61\164\164\162" => ["\x63\154\141\x73\x73" => "\x62\x74\156\40\142\x74\x6e\55\154\147\40\142\x74\x6e\55\142\x6c\x75\145"], "\x6c\141\142\x65\x6c" => "\103\x72\145\141\x74\145"]); goto c8223; c8223: return $form; goto b19cb; b19cb: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto d81c6; C0ecc: bc84b: goto e52bb; fac06: goto bc84b; goto Cd7af; f7fee: $this->formErrors = $this->getErrorMessages($form); goto fac06; d81c6: if (true === $form->isValid()) { goto Ce3e8; } goto f7fee; B29b8: try { goto B710d; Ca148: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto ff282; Ab598: throw new \Exception(sprintf("\x56\150\157\163\x74\40\x74\145\x6d\x70\x6c\x61\x74\145\40\42\45\x73\42\40\x6e\x6f\x74\40\146\157\165\156\x64\56", $vhostTemplateName)); goto b588f; ee537: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\x73\x69\164\145\x73")); goto d8825; d4157: $user = $this->getUser(); goto fd72f; ff282: dadfa: goto C6508; f05ad: f7094: goto d532f; C6930: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto C789d; e5544: $rootDirectory = sprintf("\45\163\x2f\x25\163", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\x2f"), "\57")); goto f05ad; a4f3f: F4820: goto d4157; efa96: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto b9272; Bc037: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto dadfa; } goto Ca148; C6508: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto dfba5; C789d: $session->getFlashBag()->set("\163\165\143\143\x65\163\163", $this->translator->trans("\x53\151\x74\145\40\x68\141\163\x20\142\x65\x65\156\40\x63\x72\145\141\x74\145\x64\x2e")); goto ee537; Bf48c: $phpVersion = $form->get("\160\150\160\x56\x65\x72\163\151\157\x6e")->getData(); goto d267d; d267d: $siteUser = $form->get("\x73\x69\x74\x65\x55\x73\145\x72")->getData(); goto D6847; d532f: $varnishCacheSettings = []; goto Bc037; E3f8c: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto f7094; } goto e5544; d8825: return $response; goto a10b4; fd72f: $rootDirectory = $domainName; goto E3f8c; a10b4: D758b: goto d5884; f879f: $domainName = $form->get("\x64\157\155\x61\151\156\116\x61\155\145")->getData(); goto Bf48c; fa0ac: $vhostTemplateName = $form->get("\141\x70\x70\154\x69\143\x61\x74\151\157\156")->getData(); goto f879f; b9272: if (false === is_null($vhostTemplateEntity)) { goto F4820; } goto Ab598; B710d: $session = $request->getSession(); goto fa0ac; D6847: $siteUserPassword = $form->get("\163\x69\x74\145\x55\x73\145\x72\120\x61\163\163\x77\x6f\x72\x64")->getData(); goto efa96; b588f: goto D758b; goto a4f3f; dfba5: $eventData = ["\163\151\x74\x65" => $domainName, "\166\150\157\163\x74\124\x65\x6d\x70\154\141\164\x65\116\141\155\x65" => $vhostTemplateName, "\160\x68\160\x56\145\162\163\x69\157\156" => $phpVersion, "\163\151\164\x65\125\x73\x65\162" => $siteUser]; goto C6930; d5884: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\x6e\147\x65\162", $this->translator->trans("\101\156\40\x65\x72\x72\x6f\162\x20\x68\141\x73\x20\x6f\x63\143\x75\x72\162\145\x64\x2c\40\145\162\x72\x6f\x72\40\x6d\145\x73\163\x61\x67\145\x3a\40\45\145\x72\x72\x6f\162\115\145\x73\163\141\147\x65\x25", ["\x25\x65\x72\162\157\162\x4d\145\x73\x73\141\x67\145\45" => $e->getMessage()])); } goto C0ecc; Cd7af: Ce3e8: goto B29b8; e52bb: } public function newWordPressSite(Request $request) : Response { goto af966; cd48d: if (!(true === $form->isSubmitted())) { goto B17b7; } goto F8710; A678e: E09db: goto B216d; caa48: $response = $this->redirect($this->generateUrl("\143\x6c\160\137\163\x69\164\145\x73")); goto Fdb4c; E195f: if (!(true === $request->isMethod("\x50\x4f\x53\124"))) { goto E09db; } goto cdae2; cf2a9: if (!(false === is_null($response))) { goto F5483; } goto aa3bd; B216d: $response = $this->render("\106\x72\x6f\x6e\x74\x65\x6e\144\x2f\x53\x69\x74\x65\57\x4e\x65\167\x2f\x77\x6f\x72\144\160\162\x65\163\163\x2e\150\x74\x6d\154\56\x74\x77\151\147", ["\x75\163\x65\162" => $user, "\146\x6f\x72\155" => $form->createView(), "\x66\157\162\x6d\105\x72\x72\157\x72\163" => $this->formErrors]); goto b43d2; cc2d8: if (true === $hasPermissions) { goto Bfe70; } goto caa48; de6ef: F5483: goto F7d14; af966: $hasPermissions = $this->hasPermissions(); goto cc2d8; F8710: $response = $this->handleCreateWordPressSiteForm($request, $form); goto cf2a9; eba67: return $response; goto ccd72; aa3bd: return $response; goto de6ef; cdae2: $form->handleRequest($request); goto cd48d; aefd9: Bfe70: goto Aee93; Aee93: $user = $this->getUser(); goto D091b; Fdb4c: goto df6b8; goto aefd9; F7d14: B17b7: goto A678e; D091b: $form = $this->createWordPressSiteForm(); goto E195f; b43d2: df6b8: goto eba67; ccd72: } private function createWordPressSiteForm() : Form { goto f91c0; f91c0: $form = $this->createForm("\x41\160\160\134\x46\x6f\x72\x6d\x5c\123\x69\164\145\x4e\145\167\x57\x6f\162\144\x50\162\x65\x73\163\124\171\x70\x65", [], ["\141\143\164\151\x6f\156" => $this->generateUrl("\143\154\x70\137\x73\151\164\145\137\167\x6f\x72\x64\160\162\145\x73\x73\137\x6e\x65\167"), "\x6d\x65\x74\150\157\x64" => "\120\x4f\x53\x54", "\x61\x74\164\162" => ["\x69\144" => "\156\x65\167\55\x77\x6f\162\144\x70\162\145\x73\163\x2d\163\151\164\145\55\146\157\x72\x6d"]]); goto A79a8; A79a8: $form->add("\x73\x75\142\x6d\151\164", SubmitType::class, ["\141\x74\164\x72" => ["\x63\154\141\163\x73" => "\x62\164\156\40\x62\164\156\x2d\x6c\147\x20\142\x74\156\x2d\x62\154\165\x65"], "\154\x61\142\145\x6c" => "\103\x72\145\141\x74\145"]); goto cdc46; cdc46: return $form; goto d1505; d1505: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto a03ac; F85d8: d1d8c: goto d3fb5; d3fb5: try { goto e1473; e9c3f: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto B8dbe; D5a6e: if (!(false === is_null($siteEntity))) { goto ac4fb; } goto dccad; d76c9: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto bfade; dbc76: $varnishCacheSettings = []; goto Dbf32; B5635: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto D3be7; b7970: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto b0802; a0224: $databaseEntity = $this->databaseEntityManager->createEntity(); goto B5635; f709e: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto B2f70; F628c: ac4fb: goto db37d; D6e8a: $siteUserPassword = $form->get("\163\151\x74\145\125\163\x65\162\x50\x61\x73\x73\x77\x6f\x72\x64")->getData(); goto e9c3f; dccad: $databaseName = $this->getUniqueDatabaseName($generatedName); goto A3b89; eda93: $url = sprintf("\150\164\164\x70\x73\72\57\57\45\x73", $siteEntity->getDomainName()); goto c42e9; C6a83: $siteCredentials = [$this->translator->trans("\123\151\164\x65") => [$this->translator->trans("\111\x50\x20\x41\x64\x64\162\x65\163\x73") => $instance->getIpv4PublicIp(), $this->translator->trans("\104\x6f\x6d\x61\151\156\40\116\x61\x6d\145") => sprintf("\150\164\164\160\163\72\x2f\57\45\x73", $domainName), $this->translator->trans("\123\x69\x74\145\40\x55\163\145\x72") => $siteUser, $this->translator->trans("\x50\141\163\x73\x77\157\162\144") => $siteUserPassword]]; goto D5a6e; B8dbe: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto dbc76; db37d: $session->set("\x73\151\x74\x65\x43\x72\145\x64\145\x6e\x74\151\141\154\x73", $siteCredentials); goto C2e27; f37e9: $isMultiSite = $form->get("\x6d\x75\x6c\x74\x69\123\x69\164\x65")->getData(); goto cd057; Bd3d0: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto a3eb2; A3b89: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto d0abf; Ec9d2: $databaseEntity->setSite($siteEntity); goto b7970; f81d7: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto Eac47; e1473: $user = $this->getUser(); goto cf2d3; Dcc0a: $this->siteEntityManager->updateEntity($siteEntity); goto eabdd; Da46d: $adminEmail = $form->get("\x61\x64\x6d\151\x6e\x45\x6d\141\x69\154")->getData(); goto f37e9; cd057: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto a0224; c42e9: $title = $form->get("\163\151\164\145\x54\151\x74\154\145")->getData(); goto A52b6; D3be7: $databaseEntity->setName($databaseName); goto Ec9d2; Dbf32: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto fcd3c; } goto f81d7; B2f70: $response = $this->redirect($this->generateUrl("\x63\x6c\160\137\x73\x69\164\145\137\167\x6f\x72\x64\x70\x72\x65\163\x73\137\151\x6e\x73\164\x61\154\x6c\x65\x64")); goto f81d6; a3eb2: $databaseManager->createDatabase($databaseEntity); goto Fbfe1; a9456: $siteEntity->addDatabase($databaseEntity); goto Bd3d0; d0abf: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto eda93; ca32c: $generatedName = $this->generateNameFromDomainName($domainName); goto Bf3cd; A52b6: $adminUserName = $form->get("\x61\144\155\x69\156\125\x73\145\x72\116\x61\155\x65")->getData(); goto E5a39; b1204: $databaseUserEntity->setDatabase($databaseEntity); goto bd060; C2e27: $eventData = ["\x73\x69\164\x65" => $domainName, "\163\x69\x74\x65\x55\163\x65\x72" => $siteUser]; goto f709e; B8a43: $domainName = $form->get("\144\157\155\x61\x69\156\116\x61\155\x65")->getData(); goto ca32c; Eac47: fcd3c: goto d76c9; a6ce2: $siteCredentials[$this->translator->trans("\104\x61\164\x61\x62\141\x73\x65")] = [$this->translator->trans("\110\157\x73\x74") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\120\157\x72\x74") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\x44\x61\164\x61\142\x61\163\145\40\116\141\155\145") => $databaseName, $this->translator->trans("\104\141\164\x61\142\141\x73\x65\x20\x55\x73\145\162\x20\116\141\155\145") => $databaseUserName, $this->translator->trans("\104\x61\x74\141\x62\x61\163\145\40\x55\x73\x65\x72\40\120\x61\163\x73\167\x6f\x72\144") => $databaseUserPassword]; goto C0262; cf2d3: $session = $request->getSession(); goto B8a43; E5a39: $adminPassword = $form->get("\x61\144\155\x69\156\120\x61\x73\x73\x77\157\162\144")->getData(); goto Da46d; f81d6: return $response; goto E7a7d; E2b7a: $instance = $request->attributes->get("\x69\156\163\164\141\x6e\143\x65"); goto C6a83; eabdd: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto a6ce2; a5e64: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto a63f1; b0802: $databaseUserEntity->setUserName($databaseUserName); goto a5e64; Fbfe1: $databaseManager->createUser($databaseUserEntity); goto Dcc0a; C0262: $siteCredentials["\x57\157\162\144\x50\162\x65\x73\x73"] = [$this->translator->trans("\x41\x64\155\151\x6e\x20\x45\55\x4d\x61\151\x6c") => $adminEmail, $this->translator->trans("\x41\x64\x6d\x69\x6e\x20\125\x73\145\162\40\116\x61\x6d\145") => $adminUserName, $this->translator->trans("\101\x64\x6d\x69\x6e\40\120\x61\163\x73\167\x6f\162\144") => $adminPassword, $this->translator->trans("\x41\144\155\151\156\40\x55\162\x6c") => sprintf("\x68\x74\x74\160\163\x3a\x2f\57\x25\163\x2f\x77\x70\x2d\x61\x64\x6d\x69\156\x2f", rtrim($domainName, "\x2f"))]; goto F628c; Bf3cd: $siteUser = $form->get("\163\x69\164\x65\x55\x73\x65\x72")->getData(); goto D6e8a; bd060: $databaseEntity->addUser($databaseUserEntity); goto a9456; a63f1: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto b1204; bfade: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto E2b7a; E7a7d: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\x6e\x67\x65\162", $this->translator->trans("\x41\156\40\x65\162\162\x6f\162\x20\150\141\x73\40\157\143\x63\165\162\162\145\x64\x2c\x20\145\162\x72\x6f\162\x20\155\145\163\163\141\147\145\72\40\45\x65\x72\162\157\x72\x4d\x65\x73\x73\x61\x67\145\45", ["\45\145\x72\162\x6f\162\115\145\163\163\x61\147\145\45" => $e->getMessage()])); } goto D7d87; a03ac: if (true === $form->isValid()) { goto d1d8c; } goto c55bf; c55bf: $this->formErrors = $this->getErrorMessages($form); goto bb1a2; D7d87: f453d: goto c7edc; bb1a2: goto f453d; goto F85d8; c7edc: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto B80b8; Fed0c: $wordPressInstaller = new WordPressInstaller($siteEntity); goto Bf7f6; cda85: $databaseUserName = $databaseUserEntity->getUserName(); goto e50ef; a49bf: c0308: goto a34af; Fb4e9: $databaseName = $databaseEntity->getName(); goto cda85; E6220: d2bad: goto c608a; bf3b9: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\x61\154\x75\145"], $config["\x72\141\167"]); C1ae9: } goto a49bf; c608a: $wordPressInstaller->resetPermissions(); goto a8209; E112b: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto F26b5; B80b8: $databaseHost = sprintf("\x25\163\x3a\x25\163", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto Fb4e9; a34af: if (!(true === $isMultiSite)) { goto d2bad; } goto f6462; F26b5: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto bf3b9; Ac289: b7f85: goto E6220; e50ef: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto Fed0c; b273b: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\141\154\x75\x65"], $config["\x72\x61\167"]); ec2af: } goto Ac289; Bf7f6: $wordPressInstaller->downloadAndExtractLatestVersion(); goto E112b; f6462: $this->wordPressMultiSiteConfigValues["\104\x4f\x4d\x41\111\116\137\x43\x55\x52\122\105\x4e\x54\x5f\123\111\x54\105"]["\x76\141\154\x75\x65"] = $siteEntity->getDomainName(); goto b273b; a8209: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto E0455; eef8b: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto b074b; c48e4: $siteEntity->setType(SiteEntity::TYPE_PHP); goto Ce473; a4688: $phpSite->setCertificate($certificateEntity); goto F72b8; C3e0e: $phpSettingsEntity->setSite($siteEntity); goto C97e6; B2ae3: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Df660; Eb3ad: if (!(false === is_null($subdomain) && "\x77\167\167" == $subdomain)) { goto Fa014; } goto ad93c; c9af7: $phpSiteCreator->createRootDirectory(); goto Ba0e1; c0474: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto a4688; F28f2: e049a: goto E0954; Ba0e1: $phpSiteCreator->createLogrotateFile(); goto e181b; d2bcc: $phpSiteCreator->reloadPhpFpmService(); goto Fed50; Ad366: $defaultVarnishCacheSettings = ["\x65\x6e\141\142\x6c\145\144" => false, "\x73\145\162\x76\x65\162" => self::VARNISH_CACHE_SERVER, "\143\x61\143\150\x65\124\141\x67\x50\x72\x65\x66\151\x78" => substr(md5(time()), 0, 4)]; goto eaac9; Fa36e: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto Fece5; E0455: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto Dea34; E0122: $siteEntity->setCertificate($certificateEntity); goto F86ef; c1fed: $certificateEntity->setCsr($csr); goto c8ea9; d38f0: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Cd25c; b8d8d: $siteEntity->setUserPassword($siteUserPassword); goto cb125; bb4aa: $certificateEntity = $this->certificateEntityManager->createEntity(); goto B6f1e; ddaaa: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto D4abe; a9b6b: $phpSiteCreator->reloadNginxService(); goto F61a3; C8fa8: $subdomain = $resolvedDomainName->subDomain()->toString(); goto Dd206; F81e0: $phpSite->setSubdomain($subdomain); goto c0474; D4abe: $subjectAlternativeNames = []; goto a8623; F8f2c: $constraintViolationList->addAll($phpSettingsConstraints); goto d38f0; cb125: $siteEntity->setRootDirectory($rootDirectory); goto Bbbb8; e5da2: Da2ab: goto B188b; c070c: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto fc87b; b074b: $csr = $csrGenerator->generate(); goto d153c; cc3a4: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto a13d3; B4043: $siteEntity->setUser($siteUser); goto b8d8d; ecd51: $subjectAlternativeNames[] = sprintf("\167\x77\167\x2e\45\163", $domainName); goto ee208; ee208: a025d: goto Eb3ad; Fe1fb: $siteEntity->setVhostTemplate($vhostTemplate); goto b0993; be1b3: D6922: goto A0192; C97e6: $siteConstraints = $this->validator->validate($siteEntity); goto cc3a4; e8e06: Ab958: goto Fe1fb; a737f: $phpSite->setUser($siteEntity->getUser()); goto D64c2; b0004: Fa014: goto F723a; afad3: $rsaKeyGenerator = new RsaKeyGenerator(); goto ddaaa; A0192: $phpSiteCreator->createNginxVhost(); goto a9b6b; Fed50: if (!(true === $varnishCache)) { goto D6922; } goto A6dc3; Df660: $siteEntity = $this->siteEntityManager->createEntity(); goto c48e4; e7f5a: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto a9f87; c40ad: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\x2e\56\x2f\56\x2e\x2f\x72\x65\x73\157\165\162\x63\145\x73\57\156\147\x69\156\x78\57\166\150\x6f\x73\x74\137\164\145\x6d\160\x6c\141\x74\x65\57\162\145\x64\151\x72\x65\x63\164"); goto cea5d; Afc5d: $phpSite->setDomainName($domainName); goto c4a80; Dea34: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\x2f")), "\x2f"); goto c070c; cb0d2: $vhostTemplate = new PhpVhostTemplate($phpSite); goto f8478; D7235: $constraintViolationList = new ConstraintViolationList(); goto A297b; A6dc3: $phpSite->setVarnishCache(true); goto Ad366; f19ea: $certificateEntity->setCertificate($selfSignedCertificate); goto E0122; D21fc: A7ba1: goto bb4aa; d0b10: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto c1fed; Af985: if (true === isset($_ENV["\x41\x50\x50\137\x48\x54\124\120\x33"]) && "\164\x72\165\145" === $_ENV["\x41\x50\x50\x5f\x48\124\124\x50\63"]) { goto e049a; } goto c40ad; d153c: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto c7e07; c947d: ff4a5: goto e8e06; e8fa9: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto be1b3; f8478: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto cec41; eadf3: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto D01b9; f8828: if (!(false === empty($redirectionVhostTemplate))) { goto ff4a5; } goto cddae; Fdfe1: Fa57e: goto Fd89e; cddae: $vhostTemplate = sprintf("\45\163\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto c947d; d92a6: $phpSiteCreator->createPhpFpmPool(); goto d2bcc; Ce473: $siteEntity->setDomainName($domainName); goto B4043; Cd25c: throw new \Exception(implode("\73\40", $errorMessages)); goto D21fc; cec41: $vhostTemplate->resetProcessors(); goto b5890; fc87b: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto C8fa8; F72b8: $phpSite->setPhpSettings($phpSettingsEntity); goto eadf3; cea5d: goto Da2ab; goto F28f2; B6f1e: $certificateEntity->setSite($siteEntity); goto afad3; e181b: $phpSiteCreator->createIndexPhp(); goto A0489; E0954: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\57\56\x2e\x2f\56\x2e\x2f\162\145\x73\157\x75\162\x63\x65\x73\57\x6e\x67\x69\156\170\x2f\x76\150\157\163\x74\x5f\x74\145\155\160\154\141\164\x65\x2f\162\145\x64\x69\x72\145\143\164\55\150\164\x74\160\63"); goto e5da2; A2447: $siteEntity->setPhpSettings($phpSettingsEntity); goto eef67; D64c2: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto Afc5d; B1268: $this->siteEntityManager->updateEntity($siteEntity); goto Ffb04; F61a3: $phpSiteCreator->resetPermissions(); goto cb0d2; c4a80: $phpSite->setRegistrableDomain($registrableDomain); goto F81e0; Dd206: $subdomain = false === empty($subdomain) ? $subdomain : null; goto c3467; F723a: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto eef8b; A0489: $phpSiteCreator->createPrivateKeyAndCertificate(); goto d92a6; b0993: $phpSettingsEntity = new PhpSettingsEntity(); goto A2447; D41a6: $siteEntity->setVarnishCache(true); goto Fdfe1; a8623: if (!(true === is_null($subdomain))) { goto a025d; } goto ecd51; f9265: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto e8fa9; c3467: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto B2ae3; B188b: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto f8828; ad93c: $subjectAlternativeNames[] = $registrableDomain; goto b0004; E6d0d: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Fa36e; F86ef: $phpSite = new PhpSite(); goto a737f; eef67: $phpSettingsEntity->setPhpVersion($phpVersion); goto C3e0e; Fece5: $vhostTemplate->build(); goto e7f5a; a13d3: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto A7ba1; } goto D7235; Bbbb8: if (!(false === empty($varnishCache))) { goto Fa57e; } goto D41a6; D01b9: $phpSiteCreator = new PhpSiteCreator($phpSite); goto cbd3a; Fd89e: if (!(true === is_null($subdomain) || "\167\167\167" == $subdomain)) { goto Ab958; } goto Af985; c7e07: $certificateEntity->setDefaultCertificate(true); goto d0b10; eaac9: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto f9265; A297b: $constraintViolationList->addAll($siteConstraints); goto F8f2c; c8ea9: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto f19ea; Ffb04: return $siteEntity; goto F3c5b; cbd3a: $phpSiteCreator->createUser(); goto c9af7; b5890: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto E6d0d; a9f87: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto B1268; F3c5b: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto Aa790; c5400: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto c703e; Db71c: $certificateEntity->setSite($siteEntity); goto Fc778; D620d: if (!(true === is_null($subdomain) || "\167\x77\167" == $subdomain)) { goto A86ca; } goto A7589; bb7d4: B7a8f: goto Eb54d; ea290: goto C277e; goto d774a; da16c: C277e: goto C5803; Fc778: $rsaKeyGenerator = new RsaKeyGenerator(); goto a776c; C50f5: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto C8bc2; Dfecd: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto c7543; e7f1f: $siteConstraints = $this->validator->validate($siteEntity); goto F7e2d; A0426: e878f: goto bb3c6; Eb54d: A86ca: goto F3145; B37f3: $vhostTemplate = sprintf("\x25\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto bb7d4; b672e: $subjectAlternativeNames[] = $registrableDomain; goto c0189; F9259: $nodejsSite->setRegistrableDomain($registrableDomain); goto Fa146; F7e2d: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto E3c9a; A87d0: $nodejsSite->setUser($siteEntity->getUser()); goto Be2b1; C498b: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto F6969; ba810: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto F8c83; A7589: if (true === isset($_ENV["\101\120\x50\x5f\110\x54\x54\120\63"]) && "\x74\x72\x75\x65" === $_ENV["\101\x50\x50\x5f\x48\124\x54\x50\x33"]) { goto C0705; } goto E92e0; bcdf1: $constraintViolationList->addAll($siteConstraints); goto d883b; a833f: $nodejsSite = new NodejsSite(); goto A87d0; cea5b: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto E9d51; Fef3a: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto d0fb4; Ba2ee: $certificateEntity->setCsr($csr); goto ff9e4; ff9e4: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto F78fb; E26a5: $nodejsSiteCreator->reloadNginxService(); goto f7fc2; F8c83: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto F3018; f7009: $siteEntity->setUser($siteUser); goto d27b4; b4f22: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto B8fe5; c0189: b7baf: goto ba810; F676e: $subjectAlternativeNames = []; goto Ec0d8; f7b75: $subdomain = false === empty($subdomain) ? $subdomain : null; goto Ed526; f6d50: $siteEntity->setRootDirectory($domainName); goto D620d; Fa146: $nodejsSite->setSubdomain($subdomain); goto cea5b; Be2b1: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto Ffd12; d27b4: $siteEntity->setUserPassword($siteUserPassword); goto f6d50; eb316: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto e7c15; c11f3: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Db71c; df092: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto c5400; a01fd: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Ba2ee; a776c: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto F676e; A504b: $nodejsSiteCreator->createRootDirectory(); goto e8d5d; C36f7: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Fef3a; ade7e: fb845: goto c11f3; E9d51: $nodejsSite->setCertificate($certificateEntity); goto df092; c703e: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto Fa2cd; C5803: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto Bf851; eb0d4: $nodejsSiteCreator->installNodejs(); goto C50f5; Edbf6: $vhostTemplate->resetProcessors(); goto eb316; A6cce: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto c5bae; F3145: $siteEntity->setVhostTemplate($vhostTemplate); goto Ca7bd; d883b: $constraintViolationList->addAll($nodejsSettingsConstraints); goto A6cce; ab7d2: $subdomain = $resolvedDomainName->subDomain()->toString(); goto f7b75; Be77b: return $siteEntity; goto eae23; E3c9a: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto fb845; } goto e9253; C8bc2: $nodejsSiteCreator->createNginxVhost(); goto E26a5; f27f9: $certificateEntity->setDefaultCertificate(true); goto a01fd; f717d: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto Af250; c7543: $siteEntity->setDomainName($domainName); goto f7009; bb3c6: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto b7baf; } goto b672e; e9253: $constraintViolationList = new ConstraintViolationList(); goto bcdf1; f7fc2: $nodejsSiteCreator->resetPermissions(); goto A4404; e7c15: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto f717d; A4404: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto b78bd; a4315: $nodejsSiteCreator->createNvmDirectory(); goto eb0d4; d0fb4: $this->siteEntityManager->updateEntity($siteEntity); goto Be77b; a2a90: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\x2e\56\57\56\x2e\57\162\145\x73\x6f\x75\162\x63\145\163\x2f\156\147\151\x6e\x78\x2f\166\150\157\x73\x74\137\x74\x65\x6d\x70\154\141\x74\145\57\162\x65\144\151\162\x65\143\x74\x2d\x68\x74\x74\x70\x33"); goto da16c; Ec0d8: if (!(true === is_null($subdomain))) { goto e878f; } goto c769c; c5bae: throw new \Exception(implode("\73\40", $errorMessages)); goto ade7e; Ffd12: $nodejsSite->setDomainName($domainName); goto F9259; B8fe5: $nodejsSettingsEntity->setPort($port); goto b849a; c769c: $subjectAlternativeNames[] = sprintf("\x77\x77\167\x2e\x25\x73", $domainName); goto A0426; Ca7bd: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto ee0a5; d774a: C0705: goto a2a90; eedaa: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto f27f9; A1598: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto ab7d2; D6586: $siteEntity->setCertificate($certificateEntity); goto a833f; ee0a5: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto b4f22; Aa790: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto A1598; Bf851: if (!(false === empty($redirectionVhostTemplate))) { goto B7a8f; } goto B37f3; F6969: $siteEntity = $this->siteEntityManager->createEntity(); goto Dfecd; F3018: $csr = $csrGenerator->generate(); goto eedaa; Ed526: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto C498b; Af250: $vhostTemplate->build(); goto C36f7; F78fb: $certificateEntity->setCertificate($selfSignedCertificate); goto D6586; Fa2cd: $nodejsSiteCreator->createUser(); goto A504b; E92e0: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\56\x2e\x2f\x2e\56\57\x72\x65\163\x6f\x75\162\x63\x65\x73\x2f\156\x67\151\x6e\170\57\166\x68\x6f\x73\164\x5f\164\x65\155\160\154\x61\x74\x65\x2f\x72\145\144\x69\x72\x65\x63\x74"); goto ea290; b78bd: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Edbf6; b849a: $nodejsSettingsEntity->setSite($siteEntity); goto e7f1f; e8d5d: $nodejsSiteCreator->createLogrotateFile(); goto a4315; eae23: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto c0c2d; D469b: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto f50c2; ceffb: $pythonSite->setUser($siteEntity->getUser()); goto f553b; C7442: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto D5115; D50e5: c925d: goto d7ba7; aa445: throw new \Exception(implode("\73\40", $errorMessages)); goto adb6b; df9a9: Ef08b: goto Ae724; d5ecc: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto dd367; cdc62: $pythonSiteCreator->createLogrotateFile(); goto Fcdfb; E7984: $pythonSite->setSubdomain($subdomain); goto fe7fa; ac47b: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto a5c3f; eb400: if (!(true === is_null($subdomain) || "\x77\167\167" == $subdomain)) { goto b558d; } goto a4170; dd367: $pythonSiteCreator->createNginxVhost(); goto f6e29; D7fee: $certificateEntity->setSite($siteEntity); goto b0c0b; D59b8: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto F7a04; A4197: e2671: goto Ba634; f6e29: $pythonSiteCreator->reloadNginxService(); goto bcdde; Ae724: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\57\56\x2e\x2f\x2e\56\57\x72\x65\163\x6f\165\x72\x63\145\x73\57\156\147\x69\x6e\170\x2f\166\150\x6f\x73\164\137\164\145\155\160\x6c\141\x74\x65\57\x72\x65\144\151\x72\145\x63\164\x2d\x68\x74\164\160\x33"); goto ec127; F7f3a: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto b5342; bf4ee: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Ecbf8; C253e: $siteEntity->setVhostTemplate($vhostTemplate); goto c1162; db170: $pythonSite = new PythonSite(); goto ceffb; c0c2d: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto F7f3a; D5115: $csr = $csrGenerator->generate(); goto A469b; F869e: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto C9238; Be479: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto C7def; Fcdfb: $pythonSiteCreator->writePythonVersionFile(); goto d5ecc; f16a4: B8efb: goto A2d86; Ce6aa: $siteEntity->setDomainName($domainName); goto d2b07; ec127: Dcd47: goto F869e; A51a4: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto A431e; d71fc: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Fe856; fb70d: $certificateEntity->setCertificate($selfSignedCertificate); goto ac3f2; Cb784: $siteConstraints = $this->validator->validate($siteEntity); goto b8bc1; bb22d: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto aa445; e85ab: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto Ce6aa; F38fc: $subjectAlternativeNames[] = $registrableDomain; goto D50e5; d277c: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto ec1fc; bdb88: $pythonSite->setCertificate($certificateEntity); goto dd52c; ca097: $certificateEntity->setDefaultCertificate(true); goto D469b; dd52c: $pythonSite->setPythonSettings($pythonSettingsEntity); goto Be479; A431e: $subjectAlternativeNames = []; goto f0c2f; f553b: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto C308c; f50c2: $certificateEntity->setCsr($csr); goto C1514; e952e: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto bf4ee; e5748: $pythonSettingsEntity->setPort($port); goto A2f5c; Cbabd: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto D59b8; C1514: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto fb70d; A7902: $certificateEntity = $this->certificateEntityManager->createEntity(); goto D7fee; Fe856: return $siteEntity; goto B7b0d; Ecbf8: $siteEntity = $this->siteEntityManager->createEntity(); goto e85ab; fe7fa: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto bdb88; ed05b: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\56\56\57\56\x2e\x2f\x72\145\x73\x6f\165\x72\x63\145\x73\x2f\x6e\x67\x69\156\x78\x2f\x76\150\x6f\x73\164\137\x74\x65\x6d\x70\x6c\x61\x74\145\x2f\162\145\x64\x69\x72\145\143\x74"); goto d223b; bcdde: $pythonSiteCreator->resetPermissions(); goto Cbabd; ebe0d: $constraintViolationList->addAll($siteConstraints); goto c84df; b5342: $subdomain = $resolvedDomainName->subDomain()->toString(); goto f3796; c052b: $pythonSiteCreator->createUser(); goto Dfd2e; Ccb36: $siteEntity->setRootDirectory($domainName); goto eb400; a5c3f: $this->siteEntityManager->updateEntity($siteEntity); goto d71fc; d7ba7: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto C7442; Fad4a: $pythonSite->setRegistrableDomain($registrableDomain); goto E7984; C9238: if (!(false === empty($redirectionVhostTemplate))) { goto e2671; } goto Ba2c8; d223b: goto Dcd47; goto df9a9; A771a: $siteEntity->setUserPassword($siteUserPassword); goto Ccb36; F7a04: $vhostTemplate->resetProcessors(); goto F3b0c; C7def: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto c052b; F3b0c: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto d277c; A469b: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto ca097; Dfd2e: $pythonSiteCreator->createRootDirectory(); goto cdc62; af65b: $siteEntity->setPythonSettings($pythonSettingsEntity); goto Dab24; c1162: $pythonSettingsEntity = new PythonSettingsEntity(); goto af65b; Ecff9: $vhostTemplate->build(); goto ac47b; A9d72: $constraintViolationList = new ConstraintViolationList(); goto ebe0d; ec1fc: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto Ecff9; f0c2f: if (!(true === is_null($subdomain))) { goto B8efb; } goto cd395; Dab24: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto e5748; d2b07: $siteEntity->setUser($siteUser); goto A771a; b0c0b: $rsaKeyGenerator = new RsaKeyGenerator(); goto A51a4; A2d86: if (!(false === is_null($subdomain) && "\167\167\167" == $subdomain)) { goto c925d; } goto F38fc; c84df: $constraintViolationList->addAll($pythonSettingsConstraints); goto bb22d; A2f5c: $pythonSettingsEntity->setSite($siteEntity); goto Cb784; f3796: $subdomain = false === empty($subdomain) ? $subdomain : null; goto e952e; C308c: $pythonSite->setDomainName($domainName); goto Fad4a; b8bc1: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto Efe31; Ba2c8: $vhostTemplate = sprintf("\45\x73\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto A4197; ac3f2: $siteEntity->setCertificate($certificateEntity); goto db170; a4170: if (true === isset($_ENV["\x41\120\x50\137\x48\124\124\x50\63"]) && "\164\162\x75\145" === $_ENV["\101\x50\120\x5f\x48\x54\124\x50\x33"]) { goto Ef08b; } goto ed05b; adb6b: f8056: goto A7902; cd395: $subjectAlternativeNames[] = sprintf("\x77\167\167\x2e\45\163", $domainName); goto f16a4; Efe31: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto f8056; } goto A9d72; Ba634: b558d: goto C253e; B7b0d: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto e0222; D539a: $staticSiteCreator->createLogrotateFile(); goto B9cbd; C7fc4: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto Cd0f4; F417d: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto F58b2; c7669: $certificateEntity->setDefaultCertificate(true); goto a967a; c8fa3: throw new \Exception(implode("\73\40", $errorMessages)); goto Be4d4; a7969: $staticSiteCreator->resetPermissions(); goto a181a; e670d: $staticSite->setUser($siteEntity->getUser()); goto F2faa; D47f6: if (!(false === is_null($subdomain) && "\167\167\x77" == $subdomain)) { goto e14e8; } goto B951e; B2412: if (!(true === is_null($subdomain))) { goto c2029; } goto f2a1e; Abf90: $vhostTemplate = sprintf("\x25\163\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto a4af1; Ac73c: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto b132b; C2b5c: a212d: goto Adbf1; C87f4: $certificateEntity->setCsr($csr); goto Cce46; Cd0f4: $subjectAlternativeNames = []; goto B2412; B1793: $subdomain = $resolvedDomainName->subDomain()->toString(); goto A8ebc; F4bd9: $staticSiteCreator->createNginxVhost(); goto Be61c; Adbf1: $siteEntity->setVhostTemplate($vhostTemplate); goto B6341; Df0f5: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto c7669; Cae28: $staticSite->setCertificate($certificateEntity); goto c5916; C6ea7: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto ae63f; fa4f7: $rsaKeyGenerator = new RsaKeyGenerator(); goto C7fc4; F2faa: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto c2a9f; Fa092: e14e8: goto dede7; c2a9f: $staticSite->setDomainName($domainName); goto Ece47; c5ec4: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto ac567; Cce46: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto ec19d; Efb77: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto A50e9; F775a: $siteEntity->setUserPassword($siteUserPassword); goto c3b10; e0222: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto D6a79; dede7: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto F417d; a720e: $staticSiteCreator->createUser(); goto af316; ac567: $this->siteEntityManager->updateEntity($siteEntity); goto eb398; A8ebc: $subdomain = false === empty($subdomain) ? $subdomain : null; goto e31fa; Ca845: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto c2024; D9f4e: $staticSiteCreator = new StaticSiteCreator($staticSite); goto a720e; c5916: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto D9f4e; cf524: if (!(true === is_null($subdomain) || "\167\167\x77" == $subdomain)) { goto a212d; } goto E3c64; Fe608: $constraintViolationList = new ConstraintViolationList(); goto c5afe; ec19d: $certificateEntity->setCertificate($selfSignedCertificate); goto F1a2c; E3c64: if (true === isset($_ENV["\x41\120\x50\x5f\x48\124\x54\x50\x33"]) && "\164\162\x75\x65" === $_ENV["\101\x50\x50\x5f\110\124\124\120\63"]) { goto acb6c; } goto E11c6; dd7d5: if (!count($siteConstraints)) { goto a1a11; } goto Fe608; a181a: $vhostTemplate = new StaticVhostTemplate($staticSite); goto C20bf; F1a2c: $siteEntity->setCertificate($certificateEntity); goto d116c; c3b10: $siteEntity->setRootDirectory($domainName); goto cf524; E985e: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Aef06; B9cbd: $staticSiteCreator->createIndexHtml(); goto Ad4a1; d299e: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto C6ea7; d392f: c2029: goto D47f6; B6341: $siteConstraints = $this->validator->validate($siteEntity); goto dd7d5; E11c6: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\57\56\56\57\x2e\56\x2f\x72\x65\163\x6f\x75\x72\143\145\163\57\156\147\151\x6e\170\57\166\x68\157\163\164\x5f\164\145\155\x70\x6c\x61\164\145\x2f\x72\x65\144\151\162\x65\x63\164"); goto acf44; c1583: de12e: goto Ac73c; C20bf: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto C967f; A50e9: $siteEntity = $this->siteEntityManager->createEntity(); goto Ca845; acf44: goto de12e; goto a0827; E206b: $vhostTemplate->build(); goto A8e48; F58b2: $csr = $csrGenerator->generate(); goto Df0f5; D32a9: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\57\x2e\56\57\x2e\56\x2f\x72\145\163\x6f\165\x72\143\x65\x73\x2f\156\147\151\156\170\x2f\166\x68\x6f\x73\164\137\164\x65\x6d\x70\154\141\164\145\x2f\162\145\144\x69\x72\145\143\x74\x2d\x68\x74\164\x70\63"); goto c1583; C967f: $vhostTemplate->resetProcessors(); goto d299e; d116c: $staticSite = new StaticSite(); goto e670d; f2179: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto c8fa3; D6a79: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto B1793; b132b: if (!(false === empty($redirectionVhostTemplate))) { goto e766b; } goto Abf90; e31fa: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto Efb77; a0827: acb6c: goto D32a9; f63bc: $siteEntity->setUser($siteUser); goto F775a; B951e: $subjectAlternativeNames[] = $registrableDomain; goto Fa092; Be61c: $staticSiteCreator->reloadNginxService(); goto a7969; af316: $staticSiteCreator->createRootDirectory(); goto D539a; a967a: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto C87f4; c5afe: $constraintViolationList->addAll($siteConstraints); goto f2179; c2024: $siteEntity->setDomainName($domainName); goto f63bc; a4af1: e766b: goto C2b5c; eb398: return $siteEntity; goto A672e; Aef06: $certificateEntity->setSite($siteEntity); goto fa4f7; C4ea1: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto Cae28; ae63f: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto E206b; Ece47: $staticSite->setRegistrableDomain($registrableDomain); goto F05bd; f2a1e: $subjectAlternativeNames[] = sprintf("\x77\167\167\x2e\45\x73", $domainName); goto d392f; Ad4a1: $staticSiteCreator->createPrivateKeyAndCertificate(); goto F4bd9; F05bd: $staticSite->setSubdomain($subdomain); goto C4ea1; A8e48: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto c5ec4; Be4d4: a1a11: goto E985e; A672e: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto F6ea9; ad8f0: $siteEntity->setDomainName($domainName); goto F3fe9; c5dc1: $reverseProxySite->setDomainName($domainName); goto ea049; fbab2: return $siteEntity; goto b21f1; A04d1: if (!count($siteConstraints)) { goto E24f7; } goto a307a; cdcf7: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto D56d8; b4ec8: d66d9: goto a42ef; B9169: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\x2f\x2e\56\57\x2e\x2e\x2f\162\145\x73\157\x75\x72\x63\145\163\57\156\147\151\156\170\x2f\166\150\157\x73\x74\x5f\x74\x65\155\x70\154\x61\164\x65\x2f\162\145\144\x69\162\x65\143\x74"); goto De83e; Db8ae: $siteEntity = $this->siteEntityManager->createEntity(); goto d0b69; f057b: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto F030e; e15de: $siteEntity->setUserPassword($siteUserPassword); goto D5217; Dfe6e: f4b25: goto Eb365; Aa523: E24f7: goto f0b62; ab87f: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto Fa54c; d5c76: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto C19bc; E9299: $this->siteEntityManager->updateEntity($siteEntity); goto fbab2; F3fe9: $siteEntity->setUser($siteUser); goto e15de; ca48d: $reverseProxySite->setUser($siteEntity->getUser()); goto A7fe7; c568b: $subjectAlternativeNames = []; goto C1ac2; a42ef: if (!(false === is_null($subdomain) && "\167\167\167" == $subdomain)) { goto Dd42e; } goto D738d; C1ac2: if (!(true === is_null($subdomain))) { goto d66d9; } goto D2b34; A186d: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto a0441; bcdaf: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto C5f34; d0b69: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto ad8f0; d5dcf: $subdomain = $resolvedDomainName->subDomain()->toString(); goto f6057; f0b62: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Fbedf; ed5a3: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto db00e; Fbedf: $certificateEntity->setSite($siteEntity); goto Ef2f8; Ac605: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto B24ab; Ef2f8: $rsaKeyGenerator = new RsaKeyGenerator(); goto a4382; ea049: $reverseProxySite->setRegistrableDomain($registrableDomain); goto b1731; c7847: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto d5dcf; c2502: if (true === isset($_ENV["\101\120\x50\137\x48\124\124\120\x33"]) && "\x74\162\x75\145" === $_ENV["\x41\120\x50\137\x48\x54\124\x50\x33"]) { goto f4b25; } goto B9169; ae49b: $siteEntity->setVhostTemplate($vhostTemplate); goto dfb1b; b51aa: $reverseProxySite = new ReverseProxySite(); goto ca48d; a4382: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto c568b; ec3c1: $reversProxySiteCreator->createNginxVhost(); goto D245b; D2b34: $subjectAlternativeNames[] = sprintf("\x77\167\x77\x2e\x25\163", $domainName); goto b4ec8; B2330: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Db8ae; F6ea9: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto c7847; f6057: $subdomain = false === empty($subdomain) ? $subdomain : null; goto Cd6ba; C19bc: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto E9299; D56d8: $reverseProxySite->setCertificate($certificateEntity); goto e9ac3; Dafc6: $certificateEntity->setCertificate($selfSignedCertificate); goto Ac8db; dfb1b: $siteConstraints = $this->validator->validate($siteEntity); goto A04d1; Aa311: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto ec3c1; b5114: $vhostTemplate->resetProcessors(); goto f057b; a78d9: if (!(true === is_null($subdomain) || "\167\x77\167" == $subdomain)) { goto e5fe4; } goto c2502; eb9f8: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto b5114; cd96e: $reversProxySiteCreator->resetPermissions(); goto a02da; B4374: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Dafc6; A48dd: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto Bf3bb; D573e: $constraintViolationList->addAll($siteConstraints); goto ed5a3; caf68: $reversProxySiteCreator->createRootDirectory(); goto deb4d; b1731: $reverseProxySite->setSubdomain($subdomain); goto cdcf7; a307a: $constraintViolationList = new ConstraintViolationList(); goto D573e; Fef7c: $vhostTemplate = sprintf("\45\x73\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto c8875; Ac8db: $siteEntity->setCertificate($certificateEntity); goto b51aa; e9ac3: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto Ac605; D5217: $siteEntity->setRootDirectory($domainName); goto Db06a; De83e: goto Edcf1; goto Dfe6e; Eb365: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\56\x2e\x2f\x2e\56\x2f\x72\145\x73\157\165\x72\x63\145\163\x2f\x6e\147\151\x6e\x78\x2f\x76\x68\157\x73\x74\137\164\x65\155\160\154\141\x74\x65\x2f\x72\145\x64\151\x72\145\143\x74\x2d\150\x74\x74\x70\x33"); goto Abc62; ed511: Dd42e: goto E838a; Abc62: Edcf1: goto ab87f; E838a: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto A186d; a02da: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto eb9f8; c8875: A13ab: goto C5b29; D245b: $reversProxySiteCreator->reloadNginxService(); goto cd96e; C5f34: $certificateEntity->setCsr($csr); goto B4374; db00e: throw new \Exception(implode("\x3b\40", $errorMessages)); goto Aa523; D738d: $subjectAlternativeNames[] = $registrableDomain; goto ed511; Db06a: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto a78d9; F030e: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto A48dd; Cd6ba: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto B2330; C5b29: e5fe4: goto ae49b; ba375: $reversProxySiteCreator->createUser(); goto caf68; Fa54c: if (!(false === empty($redirectionVhostTemplate))) { goto A13ab; } goto Fef7c; a0441: $csr = $csrGenerator->generate(); goto f71c5; f71c5: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto ebb6c; Bf3bb: $vhostTemplate->build(); goto d5c76; ebb6c: $certificateEntity->setDefaultCertificate(true); goto bcdaf; deb4d: $reversProxySiteCreator->createLogrotateFile(); goto Aa311; B24ab: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto ba375; A7fe7: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto c5dc1; b21f1: } public function installedWordPressSite(Request $request) : Response { goto b3626; f0f42: $siteCredentials = $session->get("\x73\151\x74\x65\103\162\x65\144\145\x6e\164\151\141\x6c\x73"); goto c96f7; b3626: $session = $request->getSession(); goto f0f42; e62f6: return $response; goto a3b2b; Bb96a: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto bc903; Aa60d: f579f: goto Bb96a; e3956: goto F457b; goto Aa60d; bc903: $response = $this->render("\x46\x72\x6f\156\x74\x65\x6e\144\x2f\123\x69\x74\145\57\116\145\167\x2f\x77\x6f\x72\x64\160\x72\x65\x73\163\x2d\151\x6e\163\164\x61\154\x6c\x65\144\56\150\x74\x6d\154\56\164\x77\151\147", ["\x73\151\164\145\x43\162\145\144\x65\x6e\x74\x69\141\154\163" => $siteCredentials]); goto e62f6; ebd42: return $response; goto D2df5; dfa43: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\163\x69\x74\x65\163")); goto e3956; c96f7: if (false === empty($siteCredentials)) { goto f579f; } goto dfa43; a3b2b: F457b: goto ebd42; D2df5: } private function renderSiteCredentials(array $siteCredentials) : string { goto B0fa3; d093c: return $renderedCredentials; goto b5248; E476d: B5d1a: goto d093c; Cca87: foreach ($siteCredentials as $section => $sectionData) { goto Ff4fa; d230e: $renderedCredentials .= "\55\55\x2d\x2d\55\55\55\55\55\x2d\x2d\x2d\x2d\55\55\x2d\55\x2d\55\55\55\x2d\55\55\x2d\x2d\55\55\55\x2d\55\55\x2d\55\x2d\55\55\x2d\55\x2d\55\55\55\55\55\55\55\55\55\x2d\x2d\55\55\55" . PHP_EOL; goto da0a6; da0a6: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\x25\x73\x3a\40\x25\163", $key, $value) . PHP_EOL; E7294: } goto E3248; A1383: $renderedCredentials .= PHP_EOL; goto c5dd9; E3248: bb56c: goto A1383; c5dd9: Fa6fc: goto Ad294; Ff4fa: $renderedCredentials .= $section . PHP_EOL; goto d230e; Ad294: } goto E476d; B0fa3: $renderedCredentials = ''; goto Cca87; b5248: } private function getVhostTemplateEntity(string $name) : mixed { goto Dd309; bf701: throw new \Exception($this->translator->trans("\x56\x68\157\x73\x74\40\x54\x65\155\160\x6c\141\164\x65\40\x25\x76\x68\x6f\163\x74\124\x65\x6d\x70\154\x61\x74\145\45\x20\x64\x6f\145\163\40\x6e\157\x74\40\x65\x78\x69\x73\x74\56", ["\x25\166\150\157\x73\164\124\145\x6d\x70\x6c\x61\x74\x65\45" => $name])); goto a8e5f; a8e5f: e62eb: goto Ecded; Bb3f2: if (!(true === is_null($vhostTemplateEntity))) { goto e62eb; } goto bf701; Ecded: return $vhostTemplateEntity; goto b3147; Dd309: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto Bb3f2; b3147: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto E2ec3; d0109: Af74b: goto b6940; b6940: return $errorMessages; goto Dff8a; F975f: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\x25\163\72\x20\45\x73", $constraint->getPropertyPath(), $constraint->getMessage()); d1504: } goto d0109; E2ec3: $errorMessages = []; goto F975f; Dff8a: } private function generateNameFromDomainName(string $domainName) : string { goto Bfcf6; F3e67: $name = $explodedRegistrableDomain[0] ?? ''; goto D8d18; dcfc6: $subdomain = $resolvedDomainName->subDomain()->toString(); goto A058e; Fd928: goto D8763; goto E92e2; ee530: if ("\167\x77\167" == $subdomain) { goto C3ed8; } goto F3e67; Bfcf6: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto D7faf; Bd8eb: $name = sprintf("\45\163\55\x25\163", $explodedRegistrableDomain[0] ?? '', implode("\55", $explodedSubdomain)); goto e0e1a; D37d5: return $name; goto E10f9; D7faf: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto dcfc6; A058e: $explodedRegistrableDomain = explode("\x2e", $registrableDomain); goto ee530; E92e2: C3ed8: goto ab0ba; Fe8e3: D8763: goto D37d5; C2dac: $explodedSubdomain = explode("\56", $subdomain); goto Bd8eb; D8d18: if (!(false === empty($subdomain))) { goto A4fa5; } goto C2dac; ab0ba: $name = $explodedRegistrableDomain[0] ?? ''; goto Fe8e3; e0e1a: A4fa5: goto Fd928; E10f9: } private function getUniqueDatabaseName(string $databaseName) : string { goto B3c51; D8e80: b488a: goto e0de2; Bf181: $i++; goto D60fa; ab066: $uniqueDatabaseName = sprintf("\45\x73\55\144\x62", $uniqueDatabaseName); goto f15c2; f15c2: Aada2: goto Cc85e; D4ff9: B2039: goto B829e; c03af: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto D7d73; e0de2: return $uniqueDatabaseName; goto dac94; de979: $databaseExists = in_array($uniqueDatabaseName, $databases); goto Bf181; Cc85e: $i = 0; goto c03af; B3c51: $uniqueDatabaseName = $databaseName; goto e6508; e6508: if (!(strlen($uniqueDatabaseName) <= 3)) { goto Aada2; } goto ab066; D7d73: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto A6801; B829e: if (!(0 < $i)) { goto A373c; } goto E5ec6; E5ec6: $uniqueDatabaseName = sprintf("\45\x73\x2d\x25\163", $databaseName, $i); goto E0e6a; A6801: $databases = $databaseConnection->getDatabases(); goto D4ff9; D60fa: if (true === $databaseExists) { goto B2039; } goto D8e80; E0e6a: A373c: goto de979; dac94: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto E356c; aedee: ffb08: goto ef79b; E554b: if (!(0 < $i)) { goto ffb08; } goto E05f7; B9bf9: B699c: goto c69e3; Dd851: e2684: goto def84; Afa01: if (false === is_null($databaseUserEntity)) { goto e9c9f; } goto B9bf9; c69e3: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto E4746; E05f7: $uniqueDatabaseUserName = sprintf("\x25\163\55\x25\x73", $databaseUserName, $i); goto aedee; f54c7: $uniqueDatabaseUserName = sprintf("\45\163\55\144\142", $uniqueDatabaseUserName); goto Dd851; ef79b: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto eefb4; E4746: return $uniqueDatabaseUserName; goto De16b; E356c: $uniqueDatabaseUserName = $databaseUserName; goto f24b9; a5cfb: e9c9f: goto E554b; def84: $i = 0; goto a5cfb; eefb4: $i++; goto Afa01; f24b9: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto e2684; } goto f54c7; De16b: } private function hasPermissions() : bool { goto Eadf1; be261: return false; goto d16a2; ec719: ded18: goto be261; c6fb4: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto ded18; } goto B6ea3; B6ea3: return true; goto ec719; Eadf1: $user = $this->getUser(); goto c6fb4; d16a2: } }
